pub struct InvalidWaveformError {
pub attempted_waveform: usize,
}Expand description
Occurs when attempting to send a command to set the channel to a waveform that does not exist.
Fields
attempted_waveform: usizeThe number that was attempted to be used as a waveform index.